@@ -108,7 +108,10 @@ FORMAT_IMPLEMENTATIONS: Dict[str, List[str]] = {
     "drf": ["aicsimageio.readers.default_reader.DefaultReader"],
     "dsc": ["aicsimageio.readers.default_reader.DefaultReader"],
     "dti": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
-    "dv": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
+    "dv": [
+        "aicsimageio.readers.dv_reader.DVReader",
+        "aicsimageio.readers.bioformats_reader.BioformatsReader",
+    ],
     "ecw": ["aicsimageio.readers.default_reader.DefaultReader"],
     "emf": ["aicsimageio.readers.default_reader.DefaultReader"],
     "eps": [
@@ -284,7 +287,10 @@ FORMAT_IMPLEMENTATIONS: Dict[str, List[str]] = {
     "mvd2": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
     "naf": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
     "nd": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
-    "nd2": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
+    "nd2": [
+        "aicsimageio.readers.nd2_reader.ND2Reader",
+        "aicsimageio.readers.bioformats_reader.BioformatsReader",
+    ],
     "ndpi": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
     "ndpis": ["aicsimageio.readers.bioformats_reader.BioformatsReader"],
     "nef": [
